==> haskell-tasty-kat-0.0.3-150-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-kat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-kat
version:              0.0.3
visibility:           public
id:                   tasty-kat-0.0.3-2qGt3x8Dyvl6dNuz4AstuX
key:                  tasty-kat-0.0.3-2qGt3x8Dyvl6dNuz4AstuX
license:              MIT
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/tasty-kat
synopsis:             Known Answer Tests (KAT) framework for tasty
description:
    Tests running from simple KATs file (different formats/helper supported)

category:             tasty-kat
abi:                  c0ce5b861891b93e7601b5a94cd07495
exposed:              True
exposed-modules:      Test.Tasty.KAT Test.Tasty.KAT.FileLoader
hidden-modules:       Test.Tasty.KAT.Internal
import-dirs:          /usr/lib/ghc-9.0.2/site-local/tasty-kat-0.0.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tasty-kat-0.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-kat
hs-libraries:         HStasty-kat-0.0.3-2qGt3x8Dyvl6dNuz4AstuX
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    tasty-1.4.3-F5jS0TcPgL077vxy1alhqa

haddock-interfaces:   /usr/share/doc/haskell-tasty-kat/html/tasty-kat.haddock
haddock-html:         /usr/share/doc/haskell-tasty-kat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-kat-0.0.3-154-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-kat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-kat
version:              0.0.3
visibility:           public
id:                   tasty-kat-0.0.3-1xANiqzpsVfK8eDXcWOrN8
key:                  tasty-kat-0.0.3-1xANiqzpsVfK8eDXcWOrN8
license:              MIT
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/tasty-kat
synopsis:             Known Answer Tests (KAT) framework for tasty
description:
    Tests running from simple KATs file (different formats/helper supported)

category:             tasty-kat
abi:                  44c8480ad95f925b09a2ece03f39c132
exposed:              True
exposed-modules:      Test.Tasty.KAT Test.Tasty.KAT.FileLoader
hidden-modules:       Test.Tasty.KAT.Internal
import-dirs:          /usr/lib/ghc-9.0.2/site-local/tasty-kat-0.0.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tasty-kat-0.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-kat
hs-libraries:         HStasty-kat-0.0.3-1xANiqzpsVfK8eDXcWOrN8
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    tasty-1.4.3-F66r8edLlMt1lhUHqLBudT

haddock-interfaces:   /usr/share/doc/haskell-tasty-kat/html/tasty-kat.haddock
haddock-html:         /usr/share/doc/haskell-tasty-kat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
